.. 01memories documentation master file, created by
   sphinx-quickstart on Thu Dec 28 09:11:46 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to 01memories's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:


Autosummary
===========

.. autosummary::
   :toctree: _autosummary

   pyframe
   repository


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
